@@ -58,6 +58,8 @@ bool GameInfo::loadFromFile(QString filename)
     _bin_path = status.value(_id + "/BinPath", "").toString();
     _data_path = status.value(_id + "/DataPath", "").toString();
     _save_timestamp = status.value(_id + "/SaveTimestamp", "").toString();
+    _json_id = status.value(_id + "/Id", "").toString();
+    _json_binary = status.value(_id + "/Binary", "").toString();
 
     return true;
 }
@@ -73,6 +75,8 @@ void GameInfo::SaveStatus()
         settings.setValue(_id + "/Version", _json_version);
         settings.setValue(_id + "/BinPath", _bin_path);
         settings.setValue(_id + "/DataPath", _data_path);
+        settings.setValue(_id + "/Id", _json_id);
+        settings.setValue(_id + "/Binary", _json_binary);
     }
     else
     {
@@ -80,6 +84,7 @@ void GameInfo::SaveStatus()
         settings.remove(_id + "/Version");
         settings.remove(_id + "/BinPath");
         settings.remove(_id + "/DataPath");
+        settings.remove(_id + "/Binary");
     }
     if (!_save_timestamp.isEmpty())
         settings.setValue(_id + "/SaveTimestamp", _save_timestamp);
@@ -110,3 +115,69 @@ bool GameInfo::ParseJson(QString json_data)
 
     return true;
 }
+
+//
+// Form 'Exec' command, add LD_PRELOAD hack if needed
+//
+QString GameInfo::Exec()
+{
+    QString env;
+
+    if (!_env.isEmpty() ||
+            !_preload.isEmpty())
+    {
+        env += "/usr/bin/env ";
+    }
+
+    if (!_env.isEmpty())
+        env += QString("%1 ")
+                .arg(_env);
+
+    if (!_preload.isEmpty())
+    {
+        env += ParsePreload(
+                    _preload.section(';', 0, 0));
+        env += ParsePreload(
+                    _preload.section(';', 1, 1));
+        env += QString(" LD_PRELOAD=%1 ")
+                .arg(GAMES_LIB_DIR"libldhack.so");
+
+    }
+
+    return QString("%1\"/opt/preenv/wrapper.sh\" "
+                    "\"%2\" "
+                    "\"%3\"")
+            .arg(env)
+            .arg(DBusName())
+            .arg(_bin_path + "/" +
+                 _json_binary.section('/', -1, -1));
+
+}
+
+
+QString GameInfo::DBusName()
+{
+    return _json_id
+            .replace('-', '_')
+            .remove(QRegExp("[^.a-zA-Z0-9_]"));
+}
+
+QString GameInfo::ParsePreload(QString section)
+{
+    if (section.isEmpty())
+        return "";
+
+    QString fromDir = section.section(':', 0, 0);
+    QString toDir = section.section(':', 1, 1);
+    toDir.replace("BIN_DIR", _bin_path);
+    toDir.replace("DATA_DIR", _data_path);
+
+    if (!toDir.endsWith('/'))
+        toDir += '/';
+
+    if (fromDir == "PowerVR")
+        return " LD_POWERVR_DIR=\"" + toDir + "\" ";
+
+    return QString(" LD_HACK_FROM=\"" + fromDir + "\" " +
+                   "LD_HACK_TO=\"" + toDir + "\" ");
+}
