@@ -49,6 +49,9 @@ public:
     bool ParseJson(QString result);
     void SaveStatus();
 
+    QString Exec();
+    QString DBusName();
+
 private:
     // Info provided by game supporters (static)
     QString _title; // may differ from stored in .ipk
@@ -79,6 +82,8 @@ private:
     QString _json_version;
     QString _json_icon; // relative path to Icon
     QString _json_id; // id string
+
+    QString ParsePreload(QString);
 };
 
 #endif // GAMEINFO_H
