@@ -1,7 +1,6 @@
 #ifndef INSTALLWINDOW_H
 #define INSTALLWINDOW_H
 
-#include <QString>
 #include "actionwindow.h"
 
 class InstallWindow : public ActionWindow 
@@ -25,9 +24,6 @@ private:
     bool Step6CreateShortcuts();
     bool Step7PostInstall();
     bool Step8ShowNotes();
-    QString GetExecHacksString();
-    QString ParsePreload(QString);
-    QString ValidatedDBusName();
 
 private slots:
     bool Step2Finished();
