@@ -173,100 +173,100 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Выполнение послеустановочных команд</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="98"/>
+        <location filename="../src/installwindow.cpp" line="60"/>
         <source>Prepare desktop shortcut</source>
         <translation>Подготовка иконок</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="107"/>
-        <location filename="../src/installwindow.cpp" line="115"/>
-        <location filename="../src/installwindow.cpp" line="121"/>
+        <location filename="../src/installwindow.cpp" line="69"/>
+        <location filename="../src/installwindow.cpp" line="77"/>
+        <location filename="../src/installwindow.cpp" line="83"/>
         <source>Cannot create directory %1</source>
         <translation>Невозможно создать каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="138"/>
+        <location filename="../src/installwindow.cpp" line="100"/>
         <source>Cannot copy icon </source>
         <translation>Невозможно скопировать иконку </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="173"/>
+        <location filename="../src/installwindow.cpp" line="124"/>
         <source>Cannot create .desktop file </source>
         <translation>Невозможно создать .desktop файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="186"/>
+        <location filename="../src/installwindow.cpp" line="137"/>
         <source>Cannot create DBUS .service file </source>
         <translation>Невозможно создать dbus .service файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="202"/>
+        <location filename="../src/installwindow.cpp" line="153"/>
         <source>Prepare files and symlinks</source>
         <translation>Подготовка файлов и ссылок</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="216"/>
+        <location filename="../src/installwindow.cpp" line="167"/>
         <source>Cannot copy binary file </source>
         <translation>Невозможно скопировать бинарный файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="251"/>
+        <location filename="../src/installwindow.cpp" line="202"/>
         <source>Unpack archive (it may take a while)</source>
         <translation>Распаковка архива (может занять немного времени)</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="271"/>
+        <location filename="../src/installwindow.cpp" line="222"/>
         <source>Cannot unpack archive:&lt;br /&gt;</source>
         <translation>Невозможно распаковать архив:&lt;br /&gt;</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="286"/>
+        <location filename="../src/installwindow.cpp" line="237"/>
         <source>Prepare directories</source>
         <translation>Подготовка каталогов</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="294"/>
+        <location filename="../src/installwindow.cpp" line="245"/>
         <source>Main property not found in Json: </source>
         <translation>Поле Main не найдено в appinfo.json: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="315"/>
-        <location filename="../src/installwindow.cpp" line="319"/>
+        <location filename="../src/installwindow.cpp" line="266"/>
+        <location filename="../src/installwindow.cpp" line="270"/>
         <source>Can&apos;t create directory %1</source>
         <translation>Не могу создать каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="333"/>
+        <location filename="../src/installwindow.cpp" line="284"/>
         <source>Extracting game info</source>
         <translation>Извлечение информации об игре</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="353"/>
+        <location filename="../src/installwindow.cpp" line="304"/>
         <source>Cannot parse JSON: </source>
         <translation>Ошибка разбора JSON: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="360"/>
+        <location filename="../src/installwindow.cpp" line="311"/>
         <source>Error parsing appinfo.json!</source>
         <translation>Ошибка парсера JSON!</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="365"/>
+        <location filename="../src/installwindow.cpp" line="316"/>
         <source>Seems to be wrong game or naming error!&lt;br /&gt;Ipk ID: %1&lt;br /&gt;Expected ID mask: %2</source>
         <translation>Ошибка в соответствии игры имени!&lt;br /&gt;ID из файла: %1&lt;br /&gt;Ожидаемая маска ID: %2</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="372"/>
+        <location filename="../src/installwindow.cpp" line="323"/>
         <source> by </source>
         <translation> от </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="385"/>
+        <location filename="../src/installwindow.cpp" line="336"/>
         <source>Checking available space</source>
         <translation>Проверка свободного места</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="396"/>
+        <location filename="../src/installwindow.cpp" line="347"/>
         <source>Available free space in /home/user/MyDocs directory is %1MB, but the game requires %2MB!</source>
         <translation>Доступное место в MyDocs каталоге - %1МБ, но игре нужно %2МБ!</translation>
     </message>
@@ -354,76 +354,81 @@ p, li { white-space: pre-wrap; }
         <translation>IPK файл:</translation>
     </message>
     <message>
-        <location filename="../src/ui/managewindow.ui" line="210"/>
-        <location filename="../src/managewindow.cpp" line="161"/>
-        <location filename="../src/managewindow.cpp" line="190"/>
+        <location filename="../src/ui/managewindow.ui" line="239"/>
+        <location filename="../src/managewindow.cpp" line="162"/>
+        <location filename="../src/managewindow.cpp" line="198"/>
         <source>Install</source>
         <translation>Установить</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="26"/>
+        <location filename="../src/ui/managewindow.ui" line="207"/>
+        <source>Play</source>
+        <translation>Играть</translation>
+    </message>
+    <message>
+        <location filename="../src/managewindow.cpp" line="27"/>
         <source>Refresh List</source>
         <translation>Обновить список</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="28"/>
+        <location filename="../src/managewindow.cpp" line="29"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="109"/>
+        <location filename="../src/managewindow.cpp" line="110"/>
         <source>Space Required</source>
         <translation>Требует места</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="111"/>
+        <location filename="../src/managewindow.cpp" line="112"/>
         <source>MB</source>
         <translation>МБ</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="153"/>
-        <location filename="../src/managewindow.cpp" line="191"/>
+        <location filename="../src/managewindow.cpp" line="154"/>
+        <location filename="../src/managewindow.cpp" line="199"/>
         <source>Find IPK file...</source>
         <translation>Найти .IPK файл...</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="165"/>
-        <location filename="../src/managewindow.cpp" line="175"/>
+        <location filename="../src/managewindow.cpp" line="166"/>
+        <location filename="../src/managewindow.cpp" line="176"/>
         <source>Uninstall</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="178"/>
+        <location filename="../src/managewindow.cpp" line="179"/>
         <source>Game installed</source>
         <translation>Игра установлена</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="180"/>
+        <location filename="../src/managewindow.cpp" line="181"/>
         <source> (version %1)</source>
         <translation> (версия %1)</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="188"/>
+        <location filename="../src/managewindow.cpp" line="196"/>
         <source>IPK file</source>
         <translation>IPK файл</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="193"/>
+        <location filename="../src/managewindow.cpp" line="201"/>
         <source>Found!</source>
         <translation>Найден!</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="196"/>
+        <location filename="../src/managewindow.cpp" line="204"/>
         <source>Not Found</source>
         <translation>Не найден</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="212"/>
+        <location filename="../src/managewindow.cpp" line="221"/>
         <source>Uninstall game?</source>
         <translation>Удалить игру?</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="213"/>
+        <location filename="../src/managewindow.cpp" line="222"/>
         <source>Are you sure you want to uninstall %1?&lt;br /&gt;You might want to backup your saves first.</source>
         <translation>Вы уверены, что хотите удалить игру %1?&lt;br /&gt;Возможно вы хотите сначала сохранить сейвы.</translation>
     </message>
